#' ApplyAttributesMapping
#'
#' Applies attributes mapping to original data
#'
#' @param originalData Original data. Required.
#' @param attrMapping List of attributes mapping between original data and internal representation.
#'   Required.
#'
#' @return data.table
#'
#' @examples
#' \dontrun{
#' ApplyAttributesMapping(originalData, attrMapping)
#' }
#'
#' @export
ApplyAttributesMapping <- function(originalData, attrMapping)
{
  stopifnot(!missing(originalData))
  stopifnot(!missing(attrMapping))

  columnSpecs <- GetListObject(system.file("referenceData/requiredColumns.R",
                                           package = "hivEstimatesAccuracy"),
                               includeFileName = FALSE)

  # Check attributes mapping
  attrMappingStatus <- GetAttrMappingStatus(attrMapping)
  if (!attrMappingStatus$Valid) {
    return(NULL)
  }

  # Keep only required variables
  oldColNames <- unname(sapply(attrMapping, "[[", 1))
  newColNames <- names(attrMapping)

  outputData <- originalData[, ..oldColNames]
  setnames(outputData, oldColNames, newColNames)

  ConvertDataTableColumns(outputData, sapply(columnSpecs, "[[", "type"))

  return(outputData)
}
