#' WriteDataFile
#'
#' Write content of a data table to file, currently only text file.\cr
#' It is a wrapper around \code{\link{WriteTextFile}}.
#'
#' @param data data.table object to save. Required.
#' @param fileName Name of the saved file. Required.
#' @param ... Additional parameters passed to \code{\link{ReadTextFile}}. Optional.
#'
#' @return NULL (invisibly)
#'
#' @examples
#' \dontrun{
#' WriteDataFile(data, fileName)
#' }
#'
#' @export
WriteDataFile <- function(data, fileName, ...)
{
  stopifnot(!missing(data))
  stopifnot(!missing(fileName))

  # Get file extension
  fileExtension <- tolower(tools::file_ext(fileName))
  if (fileExtension == "") {
    fileExtension <- "csv"
  }

  # Define default field separator
  defSep <- switch(fileExtension,
    "txt" = "\t",
    "csv" = ifelse(Sys.localeconv()[["decimal_point"]] == ",", ";", ","),
    {stop("Unsupported file extension")})

  # If separator is provided in the actual argument list (...) then use it.
  # Otherwise, use the default one.
  extraParams <- list(...)
  if ("sep" %in% names(extraParams)) {
    WriteTextFile(data, fileName, ...)
  } else {
    WriteTextFile(data, fileName, sep = defSep, ...)
  }

  return(invisible(NULL))
}
